@@ -16,64 +16,86 @@ from tempfile import gettempdir
 
 class FocusedWave(AcousticField):
 
-    def __init__(self, focal_point, **kwargs):
+    def __init__(self, focal_line, **kwargs):
         """
         Initialize the FocusedWave object.
 
         Parameters:
-        - focal_point (tuple): The focal point coordinates (x, z) in meters.
+        - focal_line (tuple): The focal line coordinates (x) in meters.
         - **kwargs: Additional keyword arguments for AcousticField initialization.
         """
         super().__init__(**kwargs)
         self.waveType = WaveType.FocusedWave
         self.kgrid.setTime(int(self.kgrid.Nt*2),self.kgrid.dt) # Extend the time grid to allow for delays
-        self.focal_point = (focal_point[0] / 1000, focal_point[1] / 1000)  
+        self.focal_line = focal_line
         self.delayedSignal = self._apply_delay()
 
     def getName_field(self):
         """
-        Generate the name for the field file based on the focal point.
+        Generate the name for the field file based on the focal line.
 
         Returns:
             str: File name for the system matrix file.
         """
         try:
-            x_focal, z_focal = self.focal_point
-            return f"field_focused_X{x_focal*1000:.2f}_Z{z_focal*1000:.2f}"
+            return f"field_focused_X{self.focal_line*1000:.2f}"
         except Exception as e:
             print(f"Error generating file name: {e}")
             return None
 
-    def _apply_delay(self):
+    def _apply_delay(self, dx=None):
         """
-        Apply a temporal delay to the signal for each transducer element to focus the wave at the desired focal point.
+        Apply a temporal delay to focus the wave at a given lateral position (x_focal) and fixed focal depth (Foc).
+    
         Returns:
-            ndarray: Array of delayed signals.
+            ndarray: Delayed signals, shape (nbPiezo, len(burst) + max_delay).
         """
         try:
-            x_focal, z_focal = self.focal_point
+            # 1. Récupération des paramètres
+            if dx is None:
+                dx = self.params['dx']
 
-            # Calculate the physical positions of the elements starting from Xrange[0]
-            element_positions = np.linspace(self.params['Xrange'][0], self.params['Xrange'][1], self.params['num_elements'])
+            c0 = self.params['c0']  # Vitesse du son (m/s)
+            num_elements = self.params['num_elements']
+            element_width = self.params['element_width']  # Largeur d'un élément (mm)
+            Foc = self.params['Foc']  # Profondeur focale (mm)
+            x_focal = self.focal_line  # Position latérale focale (mm)
 
-            # Calculate delays based on physical positions
-            delays = np.zeros(self.params['num_elements'])
-            for i in range(self.params['num_elements']):
-                distance = np.sqrt((x_focal - element_positions[i])**2 + (z_focal)**2)
-                delays[i] = (np.max(delays) - distance / self.params['c0'])  # Delay in seconds
+            # 2. Calcul de l'indice central (élément le plus proche de x_focal)
+            center_idx = int(round(x_focal / element_width))
 
+            # 3. Limites des indices pour N_piezo_Foc éléments centrés sur x_focal
+            start_idx = max(0, center_idx - self.params['N_piezoFoc']  // 2)
+            end_idx = min(num_elements - 1, start_idx + self.params['N_piezoFoc']  - 1)
+
+            # 4. Positions latérales des éléments sélectionnés (en mm)
+            selected_indices = np.arange(start_idx, end_idx + 1)
+            element_positions = selected_indices * element_width
+
+            # 5. Distance entre chaque élément sélectionné et le point focal (x_focal, Foc)
+            distances = np.sqrt((x_focal - element_positions)**2 + Foc**2)
+
+            # 6. Délais en secondes : (distance_max - distance) / c0
+            max_distance = np.max(distances)
+            delays = (max_distance - distances) / c0  # Délais en secondes
+
+            # 7. Conversion en échantillons
             delay_samples = np.round(delays / self.kgrid.dt).astype(int)
             max_delay = np.max(delay_samples)
 
-            delayed_signals = np.zeros((self.params['num_elements'], len(self.burst) + max_delay))
-            for i in range(self.params['num_elements']):
+            # 8. Application des délais (uniquement pour les éléments sélectionnés)
+            delayed_signals = np.zeros((num_elements, len(self.burst) + max_delay))
+            for i, idx in enumerate(selected_indices):
                 shift = delay_samples[i]
-                delayed_signals[i, shift:shift + len(self.burst)] = self.burst  # Apply delay
+                delayed_signals[idx, shift:shift + len(self.burst)] = self.burst
 
             return delayed_signals
+
         except Exception as e:
             print(f"Error applying delay: {e}")
             return None
+
+
         
     def plot_delay(self):
         """
