@@ -548,12 +548,31 @@ class AlgebraicRecon(Recon):
         elif not os.listdir(smatrix):
             self.experiment.saveAcousticFields(self.saveDir)
 
-        # Construct the command
+        # Vérifier que le dossier de sortie existe
+        os.makedirs(os.path.join(self.saveDir, 'results','recon'), exist_ok=True)
+
+        # Vérifier que le fichier .cdh existe
+        if not os.path.isfile(fileName):
+            raise FileNotFoundError(f"Le fichier .cdh n'existe pas : {fileName}")
+
+        # Créer une copie de l'environnement actuel et ajouter les variables CAStOR
+        env = os.environ.copy()
+
+        env.update({
+            "CASTOR_DIR": f"{self.experiment.params.reconstruction['castor_executable']}",
+            "CASTOR_CONFIG": f"{self.experiment.params.reconstruction['castor_executable']}/config",
+            "CASTOR_64bits": "1",
+            "CASTOR_OMP": "1",
+            "CASTOR_SIMD": "1",
+            "CASTOR_ROOT": "1",
+        })
+
+        # Construire la commande
         cmd = [
-            self.experiment.params.reconstruction['castor_executable'],
-            "-df", f"{self.saveDir}/{fileName}",
+            f"{self.experiment.params.reconstruction['castor_executable']}/bin/castor-recon",
+            "-df",  f"{self.saveDir}/{fileName}",
             "-opti", self.optimizer.value,
-            "-it", f"{self.numIterations}:{self.numSubsets}"  ,
+            "-it", f"{self.numIterations}:{self.numSubsets}",
             "-proj", "matrix",
             "-dout", os.path.join(self.saveDir, 'results','recon'),
             "-th", f"{ os.cpu_count()}",
